@@ -24,17 +24,21 @@
 /*
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
-#include <stdlib.h>
-#include <kapplication.h>
-#include <kstandarddirs.h>
 #include "amoranim.h"
 #include "amorpm.h"
 
+#include <KConfigBase>
+#include <KRandom>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KStandardDirs>
+#include <QtGui/QPixmap>
+
 //---------------------------------------------------------------------------
 //
 // Constructor
 //
-AmorAnim::AmorAnim(KConfigBase &config)
+AmorAnim::AmorAnim(KConfigGroup &config)
     : mMaximumSize(0, 0)
 {
     mCurrent = 0;
@@ -59,7 +63,7 @@ const QPixmap *AmorAnim::frame()
     const QPixmap *pixmap = 0;
 
     if (validFrame())
-        pixmap = AmorPixmapManager::manager()->pixmap(*mSequence.at(mCurrent));
+        pixmap = AmorPixmapManager::manager()->pixmap(mSequence.at(mCurrent));
 
     return pixmap;
 }
@@ -69,11 +73,11 @@ const QPixmap *AmorAnim::frame()
 // Read a single animation's parameters.  The config class should already
 // have its group set to the animation that is to be read.
 //
-void AmorAnim::readConfig(KConfigBase &config)
+void AmorAnim::readConfig(KConfigGroup &config)
 {
     // Read the list of frames to display and load them into the pixmap
     // manager.
-    mSequence = config.readListEntry("Sequence");
+    mSequence = config.readEntry("Sequence",QStringList());
     int frames = mSequence.count();
     for ( QStringList::Iterator it = mSequence.begin();
           it != mSequence.end();
@@ -86,31 +90,31 @@ void AmorAnim::readConfig(KConfigBase &config)
     }
 
     // Read the delays between frames.
-    QStrList list;
-    int entries = config.readListEntry("Delay",list);
-    mDelay.resize(frames);
-    for (int i = 0; i < entries && i < frames; i++)
-        mDelay[i] = atoi(list.at(i));
+    QStringList list;
+    list = config.readEntry("Delay",QStringList());
+	mDelay.resize(list.count());
+    for (int i = 0; i < list.count() && i < frames; i++)
+        mDelay[i] = list.at(i).toInt();
 
     // Read the distance to move between frames and calculate the total
     // distance that this aniamtion moves from its starting position.
-    entries = config.readListEntry("Movement",list);
+    list = config.readEntry("Movement",QStringList());
     mMovement.resize(frames);
-    for (int i = 0; i < entries && i < frames; i++)
+    for (int i = 0; i < list.count() && i < frames; i++)
     {
-        mMovement[i] = atoi(list.at(i));
+        mMovement[i] = list.at(i).toInt();
         mTotalMovement += mMovement[i];
     }
 
     // Read the hotspot for each frame.
-    entries = config.readListEntry("HotspotX",list);
+    QStringList entries = config.readEntry("HotspotX",QStringList());
     mHotspot.resize(frames);
-    for (int i = 0; i < entries && i < frames; i++)
-        mHotspot[i].setX(atoi(list.at(i)));
+    for (int i = 0; i < entries.count() && i < frames; i++)
+        mHotspot[i].setX(entries.at(i).toInt());
 
-    entries = config.readListEntry("HotspotY",list);
-    for (int i = 0; i < entries && i < frames; i++)
-        mHotspot[i].setY(atoi(list.at(i)));
+    entries = config.readEntry("HotspotY",QStringList());
+    for (int i = 0; i < entries.count() && i < frames; i++)
+        mHotspot[i].setY(entries.at(i).toInt());
 
     // Add the overlap of the last frame to the total movement.
     const QPoint &lastHotspot = mHotspot[mHotspot.size()-1];
@@ -135,13 +139,13 @@ AmorThemeManager::AmorThemeManager()
     : mMaximumSize(0, 0)
 {
     mConfig = 0;
-    mAnimations.setAutoDelete(true);
 }
 
 //---------------------------------------------------------------------------
 //
 AmorThemeManager::~AmorThemeManager()
 {
+    qDeleteAll(mAnimations);
     delete mConfig;
 }
 
@@ -149,16 +153,16 @@ AmorThemeManager::~AmorThemeManager()
 //
 bool AmorThemeManager::setTheme(const QString & file)
 {
-    mPath = locate("appdata", file);
+    mPath = KStandardDirs::locate("appdata", file);
 
     delete mConfig;
 
-    mConfig = new KSimpleConfig(mPath, true);
-    mConfig->setGroup("Config");
+    mConfig = new KConfig(mPath, KConfig::SimpleConfig);
+    KConfigGroup configGroup(mConfig, "Config");
 
     // Get the directory where the pixmaps are stored and tell the
     // pixmap manager.
-    QString pixmapPath = mConfig->readPathEntry("PixmapPath");
+    QString pixmapPath = configGroup.readPathEntry("PixmapPath", QString());
     if (pixmapPath.isEmpty())
         return false;
 
@@ -170,15 +174,16 @@ bool AmorThemeManager::setTheme(const QString & file)
     else
     {
         // relative to config file.
-        mPath.truncate(mPath.findRev('/')+1);
+        mPath.truncate(mPath.lastIndexOf('/')+1);
         mPath += pixmapPath;
     }
 
-    mStatic = mConfig->readBoolEntry("Static", false);
+    mStatic = configGroup.readEntry("Static", false);
 
     mMaximumSize.setWidth(0);
     mMaximumSize.setHeight(0);
 
+    qDeleteAll(mAnimations);
     mAnimations.clear();
 
     return true;
@@ -190,15 +195,13 @@ bool AmorThemeManager::setTheme(const QString & file)
 //
 AmorAnim *AmorThemeManager::random(const QString & group)
 {
-    QString grp( group );
+    QString grp = mStatic ? QLatin1String("Base") : group;
 
-    if (mStatic)
-	grp = "Base";
-
-    AmorAnimationGroup *animGroup = mAnimations.find(grp);
+    QHash<QString, AmorAnimationGroup*>::const_iterator it = mAnimations.find(grp);
+    AmorAnimationGroup *animGroup = it != mAnimations.end() ? *it : 0;
 
     if (animGroup) {
-	int idx = kapp->random()%animGroup->count();
+	int idx = KRandom::random()%animGroup->count();
         return animGroup->at( idx );
     }
 
@@ -214,27 +217,30 @@ bool AmorThemeManager::readGroup(const QString & seq)
     AmorPixmapManager::manager()->setPixmapDir(mPath);
 
     AmorAnimationGroup *animList = new AmorAnimationGroup;
-    animList->setAutoDelete(true);
+#ifdef __GNUC__
+#warning "kde4: fix autodelete for animList";
+#endif	
+	//animList->setAutoDelete(true);
 
     // Read the list of available animations.
-    mConfig->setGroup("Config");
-    QStrList list;
-    int entries = mConfig->readListEntry(seq, list);
+    KConfigGroup conf(mConfig, "Config");
+    QStringList list;
+    list = conf.readEntry(seq,QStringList());
 
     // Read each individual animation
-    for (int i = 0; i < entries; i++)
+    for (int i = 0; i < list.count(); i++)
     {
-        mConfig->setGroup(list.at(i));
-        AmorAnim *anim = new AmorAnim(*mConfig);
+        KConfigGroup group(mConfig, list.at(i)); 
+        AmorAnim *anim = new AmorAnim(group);
         animList->append(anim);
         mMaximumSize = mMaximumSize.expandedTo(anim->maximumSize());
     }
-
+	int entries = list.count();
     // If no animations were available for this group, just add the base anim
-    if (entries == 0)
+    if ( entries == 0)
     {
-        mConfig->setGroup("Base");
-        AmorAnim *anim = new AmorAnim(*mConfig);
+        KConfigGroup group(mConfig, "Base");
+        AmorAnim *anim = new AmorAnim(group);
         if (anim)
         {
             animList->append(anim);
@@ -244,10 +250,10 @@ bool AmorThemeManager::readGroup(const QString & seq)
     }
 
     // Couldn't read any entries at all
-    if (entries == 0)
+    if ( entries == 0)
         return false;
 
-    mAnimations.insert(seq, animList);
+    mAnimations[seq] = animList;
 
     return true;
 }
